@@ -98,8 +98,9 @@ set_config <- function(svc, cfgs = list()) {
 
 update_optional_config_parameter <- function(cfgs, profile) {
   for (cfg_param in names(.optional_config_parameter)) {
-    if (is.null(cfgs[[cfg_param]]))
+    if (is.null(cfgs[[cfg_param]])) {
       cfgs[[cfg_param]] <- .optional_config_parameter[[cfg_param]](profile)
+    }
   }
   return(cfgs)
 }
@@ -163,10 +164,11 @@ get_env <- function(variable) {
 
 # Get the name of the IAM role from the instance metadata.
 get_iam_role <- function() {
+  iam_role_response <- get_instance_metadata("iam/security-credentials")
 
-  iam_role_response <-  get_instance_metadata("iam/security-credentials")
-
-  if (is.null(iam_role_response)) return(NULL)
+  if (is.null(iam_role_response)) {
+    return(NULL)
+  }
 
   iam_role_name <- raw_to_utf8(iam_role_response$body)
 
@@ -176,22 +178,22 @@ get_iam_role <- function() {
 # Gets the instance metadata by making an http request to an instance metadata services
 # Please see security recommendations by AWS: https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/configuring-instance-metadata-service.html
 get_instance_metadata <- function(query_path = "") {
-  token_ttl <- '21600' # same approach as in boto3: https://github.com/boto/botocore/blob/master/botocore/utils.py#L376
+  token_ttl <- "21600" # same approach as in boto3: https://github.com/boto/botocore/blob/master/botocore/utils.py#L376
   # Do not get metadata when the disabled setting is on.
   if (trimws(tolower(get_env("AWS_EC2_METADATA_DISABLED"))) %in% c("true", "1")) {
     return(NULL)
   }
   # Get token timeout for IMDSv2 tokens
-  token <-  "" # Token to be used in case of more secure IMDSv2 authentication
-  #try IMDSv2  (more information): https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/configuring-instance-metadata-service.html
-  metadata_token_url <-  file.path(
+  token <- "" # Token to be used in case of more secure IMDSv2 authentication
+  # try IMDSv2  (more information): https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/configuring-instance-metadata-service.html
+  metadata_token_url <- file.path(
     "http://169.254.169.254/latest/api/token"
   )
   metadata_token_request <- new_http_request(
     "PUT",
     metadata_token_url,
     timeout = 1,
-    header=c("X-aws-ec2-metadata-token-ttl-seconds"= token_ttl)
+    header = c("X-aws-ec2-metadata-token-ttl-seconds" = token_ttl)
   )
 
   metadata_token_response <- tryCatch(
@@ -203,7 +205,7 @@ get_instance_metadata <- function(query_path = "") {
     }
   )
   if (!is.null(metadata_token_response) && metadata_token_response$status_code == 200) {
-    if (length(metadata_token_response[["body"]])>0) {
+    if (length(metadata_token_response[["body"]]) > 0) {
       token <- rawToChar(metadata_token_response[["body"]])
     }
   }
@@ -211,12 +213,12 @@ get_instance_metadata <- function(query_path = "") {
     "http://169.254.169.254/latest/meta-data",
     query_path
   )
-  if (token!="") {
+  if (token != "") {
     metadata_request <- new_http_request(
       "GET",
       metadata_url,
       timeout = 1,
-      header = c("X-aws-ec2-metadata-token"= token)
+      header = c("X-aws-ec2-metadata-token" = token)
     )
   } else {
     metadata_request <- new_http_request("GET", metadata_url, timeout = 1)
@@ -383,8 +385,8 @@ get_sts_regional_endpoint <- function(profile = "") {
 )
 
 # Ensures config is built correctly from service parameters
-build_config <- function(cfg){
-  add_list <- function(x) if(length(x) == 0) NULL else x
+build_config <- function(cfg) {
+  add_list <- function(x) if (length(x) == 0) NULL else x
 
   creds <- list()
   credentials <- list()
