@@ -1,5 +1,6 @@
 #' @include struct.R
 #' @include url.R
+#' @include util.R
 NULL
 
 # Construct an HTTP request object.
@@ -63,7 +64,7 @@ new_http_request <- function(method, url, body = NULL, close = FALSE, connect_ti
     method <- "GET"
   }
   if (!valid_method(method)) {
-    stop(sprintf("invalid method: %s", method))
+    stopf("invalid method: %s", method)
   }
   u <- parse_url(url)
   req <- HttpRequest(
@@ -120,14 +121,14 @@ issue <- function(http_request) {
 
   # utilize httr to write to disk
   dest <- NULL
-  if(!is.null(http_request$dest)) {
-    dest <- httr::write_disk(http_request$dest)
+  if (!is.null(http_request$dest)) {
+    dest <- httr::write_disk(http_request$dest, TRUE)
   }
   r <- with_paws_verbose(
     httr::VERB(
       method,
       url = url,
-      config = c(httr::add_headers(.headers=headers), dest),
+      config = c(httr::add_headers(.headers = headers), dest),
       body = body,
       timeout
     )
@@ -139,7 +140,7 @@ issue <- function(http_request) {
     content_length = as.integer(httr::headers(r)$`content-length`),
     # Prevent reading in data when output is set
     body = (
-      if(is.null(http_request$dest)) httr::content(r, as = "raw") else raw()
+      if (is.null(http_request$dest)) httr::content(r, as = "raw") else raw()
     )
   )
 
@@ -163,7 +164,7 @@ is_compressed <- function(http_response) {
   }
 
   if (content_encoding == "gzip") {
-    bits_to_int <- function(x) sum(as.integer(x) * 2^(1:length(x)-1))
+    bits_to_int <- function(x) sum(as.integer(x) * 2^(1:length(x) - 1))
     cmf <- http_response$body[1]
     flg <- http_response$body[2]
     compression_method <- bits_to_int(rawToBits(cmf)[1:4])
