@@ -46,7 +46,6 @@ Request <- struct(
   config = Config(),
   client_info = ClientInfo(),
   handlers = Handlers(),
-
   retryer = list(),
   time = 0,
   operation = "",
@@ -65,13 +64,9 @@ Request <- struct(
   signed_header_vals = list(),
   last_signed_at = NULL,
   disable_follow_redirects = FALSE,
-
   expire_time = 0,
-
   context = list(),
-
   built = FALSE,
-
   safe_body = ""
 )
 
@@ -103,7 +98,6 @@ Request <- struct(
 #'
 #' @export
 new_request <- function(client, operation, params, data, dest = NULL) {
-
   method <- operation$http_method
   if (is.null(method)) {
     method <- "POST"
@@ -128,7 +122,6 @@ new_request <- function(client, operation, params, data, dest = NULL) {
     config = client$config,
     client_info = client$client_info,
     handlers = client$handlers,
-
     retryer = NULL, # Implement retryers.
     time = Sys.time(),
     expire_time = 0,
@@ -162,7 +155,6 @@ new_request <- function(client, operation, params, data, dest = NULL) {
 #'
 #' @export
 send_request <- function(request) {
-
   request <- sign(request)
 
   if (!is.null(request$error)) {
@@ -173,16 +165,11 @@ send_request <- function(request) {
   request <- unmarshal_meta(request)
   request <- validate_response(request)
 
-  if (!is.null(request$error)) {
-    request <- unmarshal_error(request)
-    stop(aws_error(request$error))
-  }
+  request <- retry(request)
 
   request <- unmarshal(request)
 
-  out <- get_request_output(request)
-
-  return(out)
+  return(request[["data"]])
 }
 
 #-------------------------------------------------------------------------------
