@@ -38,3 +38,11 @@ test_that("Reads in values with spaces around the equal sign", {
   expect_equal(content[[profile]][["arg1"]], "value1")
   expect_equal(content[[profile]][["arg2"]], "value2")
 })
+
+test_that("Reads in values with nested content", {
+  content <- read_ini("data_ini")
+  profile <- "nested"
+  expect_equal(content[[profile]][["nested1"]], list(arg1 = "value1", arg2 = "value2"))
+  expect_equal(content[[profile]][["nested2"]], list(arg4 = "value4"))
+  expect_equal(content[[profile]][["arg3"]], "value3")
+})
